Crate kcr_flux_framework_org

Crate kcr_flux_framework_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the flux-framework.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

flux-framework.org/v1alpha1

  • MiniCluster

flux-framework.org/v1alpha2

  • MiniCluster

Modules

v1alpha1
v1alpha2